bc.b: Broadcasted Boolean Operations

bc.bR Documentation

Broadcasted Boolean Operations

Description

The bc.b() method performs broadcasted logical (or Boolean) operations on 2 arrays.

Please note that these operations will treat the input as logical.
Therefore, something like bc.b(1, 2, "==") returns TRUE, because both 1 and 2 are TRUE when treated as logical.

For regular relational operators, see bc.rel.

Usage

bc.b(x, y, op, ...)

## S4 method for signature 'ANY'
bc.b(x, y, op)

Arguments

x, y

conformable vectors/arrays of type logical, numeric, or raw.
Note that input with type of double will be coerced to integer.

op

a single string, giving the operator.
Supported Boolean operators: &, |, xor, nand, nor
Supported relational operators: ==, !=, <, >, <=, >=.
"nand" is defined here as !(x & y), and "nor" is defined here as !(x | y).

...

further arguments passed to or from methods.

Value

Normally:
A logical array/vector as a result of the broadcasted Boolean operation.

If both x and y are type of raw:
A raw array/vector as a result of the broadcasted Boolean operation, where 01 codes for TRUE and 00 codes for FALSE.
This is convenient as raw requires less memory space than logical.

See Also

broadcast_operators

Examples

x.dim <- c(4:2)
x.len <- prod(x.dim)
x.data <- sample(c(TRUE, FALSE, NA), x.len, TRUE)
x <- array(x.data, x.dim)
y <- array(1:50, c(4,1,1))

bc.b(x, y, "&")
bc.b(x, y, "|")
bc.b(x, y, "xor")
bc.b(x, y, "nand")
bc.b(x, y, "==")
bc.b(x, y, "!=")


broadcast documentation built on Aug. 20, 2026, 9:08 a.m.

Related to bc.b in broadcast...