View source: R/cast_hier2dim.R
| cast_hier2dim | R Documentation |
cast_hier2dim() casts a hierarchical/nested list into a dimensional list
(i.e. an array of type list).
This method comes with 2 helper functions:
hier2dim and hiernames2dimnames methods.
See their help page for details.
cast_hier2dim(x, ...)
## Default S3 method:
cast_hier2dim(
x,
in2out = TRUE,
maxdepth = 16L,
recurse_all = FALSE,
padding = list(NULL),
direction.names = 0L,
...
)
x |
a nested list. |
... |
further arguments passed to or from methods. |
in2out, recurse_all |
see broadcast_casting. |
maxdepth |
a single, positive integer,
giving the maximum depth to recurse into the list. |
padding |
a list of length |
direction.names |
see argument |
An array of type list, with the dimensions given by hier2dim.
If the output needs padding (indicated by hier2dim),
the output will have more elements than x,
filled with a padding value (as specified in the padding argument).
If direction.names = 0 (default), the result will not have any dimnames;
the dimnames can then still be constructed using hiernames2dimnames.
If direction.names is 1 or -1, the result will have dimnames.
broadcast_casting, hier2dim, hiernames2dimnames
# Example 1: Basics ====
x <- list(
group1 = list(
class1 = list(
height = rnorm(10, 170),
weight = rnorm(10, 80),
sex = sample(c("M", "F", NA), 10, TRUE)
),
class2 = list(
height = rnorm(10, 170),
weight = rnorm(10, 80),
sex = sample(c("M", "F", NA), 10, TRUE)
)
),
group2 = list(
class1 = list(
height = rnorm(10, 170),
weight = rnorm(10, 80),
sex = sample(c("M", "F", NA), 10, TRUE)
),
class2 = list(
height = rnorm(10, 170),
weight = rnorm(10, 80),
sex = sample(c("M", "F", NA), 10, TRUE)
)
)
)
# predict what dimensions `x` would have if casted as dimensional:
hier2dim(x)
x2 <- cast_hier2dim(x) # cast as dimensional
# since the original list uses the same names for all elements within the same depth,
# dimnames can be set easily:
dimnames(x2) <- hiernames2dimnames(x)
print(x2)
################################################################################
# Example 2: Cast from outside to inside ====
x <- list(
group1 = list(
class1 = list(
height = rnorm(10, 170),
weight = rnorm(10, 80),
sex = sample(c("M", "F", NA), 10, TRUE)
),
class2 = list(
height = rnorm(10, 170),
weight = rnorm(10, 80),
sex = sample(c("M", "F", NA), 10, TRUE)
)
),
group2 = list(
class1 = list(
height = rnorm(10, 170),
weight = rnorm(10, 80),
sex = sample(c("M", "F", NA), 10, TRUE)
),
class2 = list(
height = rnorm(10, 170),
weight = rnorm(10, 80),
sex = sample(c("M", "F", NA), 10, TRUE)
)
)
)
# by default, `in2out = TRUE`;
# for this example, `in2out = FALSE` is used
# predict what dimensions `x` would have if casted as dimensional:
hier2dim(x, in2out = FALSE)
x2 <- cast_hier2dim(x, in2out = FALSE) # cast as dimensional
# since the original list uses the same names for all elements within the same depth,
# dimnames can be set easily:
# because in2out = FALSE, go from the shallow names to the deeper names:
dimnames(x2) <- hiernames2dimnames(x, in2out = FALSE)
print(x2)
################################################################################
# Example 3: padding ====
# For Example 3, take the same list as before, but remove x$group1$class2:
x <- list(
group1 = list(
class1 = list(
height = rnorm(10, 170),
weight = rnorm(10, 80),
sex = sample(c("M", "F", NA), 10, TRUE)
)
),
group2 = list(
class1 = list(
height = rnorm(10, 170),
weight = rnorm(10, 80),
sex = sample(c("M", "F", NA), 10, TRUE)
),
class2 = list(
height = rnorm(10, 170),
weight = rnorm(10, 80),
sex = sample(c("M", "F", NA), 10, TRUE)
)
)
)
hier2dim(x) # as indicated here, dimension 2 (i.e. columns) will have padding
# casting this to a dimensional list will resulting in padding with `NULL`:
x2 <- cast_hier2dim(x)
print(x2)
# The `NULL` values are added for padding.
# This is because all slices of the same dimension need to have the same number of elements.
# For example, all rows need to have the same number of columns.
# one can also use custom padding:
x2 <- cast_hier2dim(x, padding = list(~ "this is padding"))
print(x2)
dimnames(x2) <- hiernames2dimnames(x)
print(x2)
# we can also use in2out = FALSE:
x2 <- cast_hier2dim(x, in2out = FALSE, padding = list(~ "this is padding"))
dimnames(x2) <- hiernames2dimnames(x, in2out = FALSE)
print(x2)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.