| bc.bit | R Documentation |
The bc.bit() method
performs broadcasted bit-wise operations
on pairs of arrays, where both arrays are of type raw or both arrays are of type integer.
bc.bit(x, y, op, ...)
## S4 method for signature 'ANY'
bc.bit(x, y, op)
x, y |
conformable raw or integer (32 bit) vectors/arrays. |
op |
a single string, giving the operator. |
... |
further arguments passed to or from methods. |
The "&", "|", "xor", "nand" and "nor" operators given in bc.bit()
perform BIT-WISE AND, OR, XOR, NAND and NOR operations, respectively.
The relational operators given in bc.bit() perform BIT-WISE relational operations:
"==" is equivalent to bit-wise !xor(x, y), but faster;
"!=" is equivalent to bit-wise xor(x, y);
"<" is equivalent to bit-wise (!x & y), but faster;
">" is equivalent to bit-wise (x & !y), but faster;
"<=" is equivalent to bit-wise (!x | y), but faster;
">=" is equivalent to bit-wise (x | !y), but faster.
The "<<" and ">>" operators perform bit-wise left-shift and right-shift,
respectively,
on x by unit y.
For these shift operations,
y being larger than the number of bits of x results in an error.
Shift operations are only supported for type of raw.
For bit-wise operators:
An array of the same type as x and y,
as a result of the broadcasted bit-wise operation.
broadcast_operators
x.dim <- c(4:2)
x.len <- prod(x.dim)
x.data <- as.raw(0:10)
y.data <- as.raw(10:0)
x <- array(x.data, x.dim)
y <- array(y.data, c(4,1,1))
bc.bit(x, y, "&")
bc.bit(x, y, "|")
bc.bit(x, y, "xor")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.