| dropnests | R Documentation |
dropnests() drops redundant nesting of a list.
It is the hierarchical equivalent to the dimensional base::drop() function.
dropnests(x, ...)
## Default S3 method:
dropnests(x, maxdepth = 16L, recurse_all = FALSE, ...)
x |
a list |
... |
further arguments passed to or from methods. |
maxdepth |
a single, positive integer,
giving the maximum depth to recurse into the list. |
recurse_all |
see broadcast_casting. |
A list without redundant nesting.
Attributes are preserved.
broadcast_casting
x <- list(
a = list(list(list(list(1:10)))),
b = list(1:10)
)
print(x)
dropnests(x)
# recurse_all demonstration ====
x <- list(
a = list(list(list(list(1:10)))),
b = data.frame(month.abb, month.name),
c = data.frame(month.abb),
d = array(list(1), c(1,1,1))
)
dropnests(x) # by default, recurse_all = FALSE
dropnests(x, recurse_all = TRUE)
# maxdepth demonstration ====
x <- list(
a = list(list(list(list(1:10)))),
b = list(1:10)
)
print(x)
dropnests(x) # by default, maxdepth = 16
dropnests(x, maxdepth = 3L)
dropnests(x, maxdepth = 1L) # returns `x` unchanged
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.